==> helix-0.6.7-src.zip: helix-0.6.7/helix-core/src/test/java/org/apache/helix/mock/participant/MockBootstrapStateModel.java <==
package org.apache.helix.mock.participant;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.helix.NotificationContext;
import org.apache.helix.model.Message;
import org.apache.helix.participant.statemachine.StateModel;
import org.apache.helix.participant.statemachine.StateModelInfo;
import org.apache.helix.participant.statemachine.Transition;
import org.apache.log4j.Logger;

// mock Bootstrap state model
@StateModelInfo(initialState = "OFFLINE", states = {
    "ONLINE", "BOOTSTRAP", "OFFLINE", "IDLE"
})
public class MockBootstrapStateModel extends StateModel {
  private static Logger LOG = Logger.getLogger(MockBootstrapStateModel.class);

  // Overwrite the default value of intial state
  MockBootstrapStateModel() {
    _currentState = "IDLE";
  }

  @Transition(to = "OFFLINE", from = "IDLE")
  public void onBecomeOfflineFromIdle(Message message, NotificationContext context) {
    LOG.info("Become OFFLINE from IDLE");
  }

  @Transition(to = "BOOTSTRAP", from = "OFFLINE")
  public void onBecomeBootstrapFromOffline(Message message, NotificationContext context) {
    LOG.info("Become BOOTSTRAP from OFFLINE");
  }

  @Transition(to = "ONLINE", from = "BOOSTRAP")
  public void onBecomeOnlineFromBootstrap(Message message, NotificationContext context) {
    LOG.info("Become ONLINE from BOOTSTRAP");
  }

  @Transition(to = "OFFLINE", from = "ONLINE")
  public void onBecomeOfflineFromOnline(Message message, NotificationContext context) {
    LOG.info("Become OFFLINE from ONLINE");
  }
}

==> helix-0.7.1-src.zip: helix-0.7.1/helix-core/src/test/java/org/apache/helix/mock/participant/MockBootstrapStateModel.java <==
package org.apache.helix.mock.participant;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.helix.NotificationContext;
import org.apache.helix.api.TransitionHandler;
import org.apache.helix.model.Message;
import org.apache.helix.participant.statemachine.StateModelInfo;
import org.apache.helix.participant.statemachine.Transition;
import org.apache.log4j.Logger;

// mock Bootstrap state model
@StateModelInfo(initialState = "OFFLINE", states = {
    "ONLINE", "BOOTSTRAP", "OFFLINE", "IDLE"
})
public class MockBootstrapStateModel extends TransitionHandler {
  private static Logger LOG = Logger.getLogger(MockBootstrapStateModel.class);

  // Overwrite the default value of intial state
  MockBootstrapStateModel() {
    _currentState = "IDLE";
  }

  @Transition(to = "OFFLINE", from = "IDLE")
  public void onBecomeOfflineFromIdle(Message message, NotificationContext context) {
    LOG.info("Become OFFLINE from IDLE");
  }

  @Transition(to = "BOOTSTRAP", from = "OFFLINE")
  public void onBecomeBootstrapFromOffline(Message message, NotificationContext context) {
    LOG.info("Become BOOTSTRAP from OFFLINE");
  }

  @Transition(to = "ONLINE", from = "BOOSTRAP")
  public void onBecomeOnlineFromBootstrap(Message message, NotificationContext context) {
    LOG.info("Become ONLINE from BOOTSTRAP");
  }

  @Transition(to = "OFFLINE", from = "ONLINE")
  public void onBecomeOfflineFromOnline(Message message, NotificationContext context) {
    LOG.info("Become OFFLINE from ONLINE");
  }
}
